#!/usr/bin/env node

/**
 * Tmplify prototype.
 */

"use strict";

process.chdir(__dirname + '/..');

const path = require('path'),
    fs = require('fs'),
    apeTasking = require('ape-tasking'),
    tmplconv = require('tmplconv');

const scff = require('../lib');

let demo = path.dirname(require.resolve('apeman-demo-mock/package.json'));

apeTasking.runTasks('tmplify', [
    (callback) => {
        tmplconv.tmplify(demo, 'asset/tmpl', {
            clean: true,
            mode: '444',
            pattern: [
                '**/*.*',
                '.*',
                'src/.pages.json',
                '*/.*.bud',
                '*/.*.hbs'
            ],
            ignore: [
                'node_modules/**/*.*',
                '.sass-cache/**/*.*',
                '.DS_Store',
                '.svg'
            ],
            data: {
                'github_repository': "apeman-demo-labo/apeman-demo-mock",
                'package_name': 'apeman-demo-mock',
                'package_description': 'Demo of mockup project.',
                'author_name': 'okunishinishi',
                'author_email': 'okunishitaka.com@gmail.com',
                'author_url': 'http://okunishitaka.com'
            },
            prefix: scff.prefix,
            suffix: scff.suffix
        }, callback);
    },
    (callback) => {
        tmplconv.tmplify(__dirname + '/..', 'asset/tmpl', {
            pattern: [
                '.gitignore'
            ],
            prefix: scff.prefix,
            suffix: scff.suffix
        }, callback);
    },
    function (callback) {
        let filename = require.resolve('../asset/tmpl/package.json.tmpl');
        let str = fs.readFileSync(filename).toString();
        let pkg = JSON.parse(str);
        fs.chmodSync(filename, '644');
        fs.writeFileSync(filename, JSON.stringify({
            name: pkg.name,
            version : '1.0.0',
            description:pkg.description,
            main:pkg.main,
            scripts:pkg.scripts,
            repository: pkg.repository.url.split(/\//g).slice(-1).join('/').replace(/\.git$/, ''),
            keywords:pkg.keywords,
            author:pkg.author,
            license:pkg.license,
            bugs:pkg.bugs,
            homepage:pkg.homepage,
            dependencies:pkg.dependencies,
            devDependencies:pkg.devDependencies,
            engines:pkg.engines
        }, null, 2));
        fs.chmodSync(filename, '444');
        callback(null);
    }
], true);
